Crasheye Windows SDK
====




## 使用

### 编译时

`#include "Crasheye.hpp"`, 把 `include/Crasheye.hpp` 加到项目中.

API:

```
  /**
  * 初始化 CrasheyeSdk. 
  * 
  * 崩溃收集相关的(如设置SEH,VEH等)一系列初始化操作.
  *
  * 本接口调用后会产生一条报活信息, 如需设置 url, 
  * 请先调用 SetURL, 再调用本接口.
  *
  * @param  strAppkey   平台申请的当前应用 appkey
  * @param  strVersion  应用当前版本号
  * @param  strChannel  应用的渠道号
  * @return 是否成功初始化
  */
  BOOL Crasheye::Init(const char* strAppkey, const char* strVersion, const char* strChannel);

  /**
  * 反初始化 CrasheyeSdk. 
  * 
  * 释放 Init 阶段注册的异常处理器. 
  * 在程序正常退出时调用.
  *
  */
  void Crasheye::UnInit();

  /**
  * 设置上报路径. 
  * 
  * 目前支持 3 种路径
  *   internal_cn => 国内自研项目
  *   internal_us => 海外自研项目
  *   external    => 外部项目
  *
  * 若不设置, 默认是 external
  *
  * 若要设置, 建议在 Init 之前调用.
  *
  * @param  szUrl  internal_cn/internal_us/external/internal_oversea 三选一.
  * @return 是否成功设置
  */
  BOOL Crasheye::SetURL(const char* szUrl);

  /**
  * 标记当前版本为调试版本
  * 
  * 若要设置, 建议在 Init 之前调用.
  *
  * @return 是否成功设置
  */
  BOOL Crasheye::SetBeta();

  /**
  * 设置用户id. 
  *
  * @param  szUserIdentifier  项目内部的用户id
  * @return 是否成功设置
  */
  BOOL Crasheye::SetUserIdentifier(const char* szUserIdentifier);

  /**
  * 添加额外上报信息.
  *
  * 以键值对的形式添加额外信息, 添加的信息会被包含着崩溃报告中随报告一同上报.
  *
  * @param  szKey   键
  * @param  szValue 值
  * @return 是否成功添加
  */
  BOOL Crasheye::AddExtraData(const char* szKey, const char* szValue);

  /**
  * 添加额外上报日志(文件).
  *
  * 添加的文件会被包含着崩溃报告中随报告一同上报.
  *
  * @param  szCollectFile   需要额外收集的文件
  * @return 是否成功添加
  */
  BOOL Crasheye::AddCustomLog(const char* szCollectFile);
  
  /**
  * 添加自定义日志文件夹.
  *
  * 最新的log文件会被包含着崩溃报告中随报告一同上报.
  *
  * @param  szCollectLogDirectory   需要收集的自定义log文件夹
  * @return 是否成功添加
  */
  BOOL AddCustomLogDirectory(const char* szCollectLogDirectory)

  /**
  * 设置崩溃回调
  *
  * 设置崩溃发生时的回调, 回调会在报告文件写入完成后被调用.
  * 回调函数签名为 
  *   void(*FnOnCrashCallback)(BOOL bCaptureSucceed, const char* cpszCrashReportFile);
  *   // @param bCaptureSucceed      是否成功捕获
  *   // @param cpszCrashReportFile  报告文件名
  *
  * 注意: 回调发生时报告文件已经生成, 此时再调用 AddExtraData 和 AddCustomLog 添加的内容, 不会被加到报告中.
  * @param  szCollectFile   需要额外收集的文件
  * @return 是否成功添加
  */
  BOOL Crasheye::SetCrashCallback(FnOnCrashCallback pCallback);

  /**
  * 设置Dump是否强制上报（忽略玩家在DumpReport界面上的选择）
  *
  * 若要设置, 建议在 Init 之前调用.
  *
  * @param  isForceUpload   是否设置Dump强制上报
  * @return 是否成功设置
  */
  BOOL SetForceUpload(BOOL isForceUpload);

  /**
  * 发送脚本异常
  *
  * @param errorTitle 错误的标题
  * @param stacktrace 异常的详细内容
  * @param language   脚本语言
  * @return 是否成功设置
  */
  BOOL SendScriptException(const char* strErrorTitle, const char* strStackTrace, const char* strLanguage);

  /**
  * 处理系统的异常指针
  *（此指针指向的结构体包含与计算机无关的异常说明和异常发生时处理器状态的特定于处理器的说明）
  *
  * 若要设置, 建议在 Init 之后调用.
  * 
  * @param ExceptionInfo 异常指针
  * @return 是否成功设置
  */
  BOOL OnCrashCallback(LPEXCEPTION_POINTERS ExceptionInfo);

  /**
  * 推送log信息流给dump模块（宕机时会写到dumper日志中）
  *
  * @param cpszMessage log信息流
  * @return 是否成功设置
  */
  BOOL PushLogTrace(const char* cpszMessage)
```

#### 运行时

把 `Dumper64.dll` 和 `DumpReport64.exe` 放在与应用exe文件同一目录下即可.

